@@ -436,7 +436,7 @@ class Lookup:
 						if num == 0:
 							color_progress=Fore.cyan	
 						if not short:
-							msg=f"{color_progress}{num}{Style.reset}/{Fore.light_red}{ct-1}{Style.reset} ->{r}\n"
+							msg=std_colorize(r,num,ct)
 							'''
 							extras=session.query(EntryDataExtras).filter(EntryDataExtras.EntryId==r.EntryId).all()
 							extras_ct=len(extras)
@@ -449,7 +449,8 @@ class Lookup:
 							msg+=mtext
 							'''
 						else:
-							msg=f"{color_progress}{num}{Style.reset}/{Fore.light_red}{ct-1}{Style.reset} ->{r.seeShort()}\n"
+							#msg=f"{color_progress}{num}{Style.reset}/{Fore.light_red}{ct-1}{Style.reset} ->{}\n"
+							msg=std_colorize(r.seeShort(),num,ct)
 							if extras:
 								extras_items=session.query(EntryDataExtras).filter(EntryDataExtras.EntryId==r.EntryId).all()
 								extras_ct=len(extras_items)
